### R code from vignette source 'indicspeciesTutorial.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: indicspeciesTutorial.Rnw:19-20
###################################################
options(width=67)


###################################################
### code chunk number 2: indicspeciesTutorial.Rnw:26-27
###################################################
library(indicspecies)


###################################################
### code chunk number 3: indicspeciesTutorial.Rnw:34-35
###################################################
data(wetland)


###################################################
### code chunk number 4: indicspeciesTutorial.Rnw:41-43
###################################################
groups = c(rep(1, 17), rep(2, 14), rep(3,10))
groups


###################################################
### code chunk number 5: indicspeciesTutorial.Rnw:46-49
###################################################
wetkm = kmeans(wetland, centers=3)
groupskm = wetkm$cluster
groupskm


###################################################
### code chunk number 6: indicspeciesTutorial.Rnw:60-62
###################################################
indval = multipatt(wetland, groups, 
                   control = permControl(nperm=999)) 


###################################################
### code chunk number 7: indicspeciesTutorial.Rnw:69-70
###################################################
summary(indval) 


###################################################
### code chunk number 8: indicspeciesTutorial.Rnw:78-79
###################################################
summary(indval, indvalcomp=TRUE)


###################################################
### code chunk number 9: indicspeciesTutorial.Rnw:85-86
###################################################
summary(indval, alpha=1)


###################################################
### code chunk number 10: indicspeciesTutorial.Rnw:89-90
###################################################
indval$sign


###################################################
### code chunk number 11: indicspeciesTutorial.Rnw:96-99
###################################################
wetlandpa = as.data.frame(ifelse(wetland>0,1,0))
phi = multipatt(wetlandpa, groups, func = "r", 
                control = permControl(nperm=999)) 


###################################################
### code chunk number 12: indicspeciesTutorial.Rnw:104-106
###################################################
phi = multipatt(wetlandpa, groups, func = "r.g", 
                control = permControl(nperm=999)) 


###################################################
### code chunk number 13: indicspeciesTutorial.Rnw:112-113
###################################################
summary(phi)


###################################################
### code chunk number 14: indicspeciesTutorial.Rnw:118-119
###################################################
round(head(phi$str),3)


###################################################
### code chunk number 15: indicspeciesTutorial.Rnw:122-123
###################################################
round(head(indval$str),3)


###################################################
### code chunk number 16: indicspeciesTutorial.Rnw:133-136
###################################################
indvalori = multipatt(wetland, groups, duleg = TRUE, 
                      control = permControl(nperm=999)) 
summary(indvalori)


###################################################
### code chunk number 17: indicspeciesTutorial.Rnw:141-144
###################################################
indvalrest = multipatt(wetland, groups, max.order = 2, 
                       control = permControl(nperm=999)) 
summary(indvalrest)


###################################################
### code chunk number 18: indicspeciesTutorial.Rnw:152-155
###################################################
indvalrest = multipatt(wetland, groups, restcomb = c(1,2,3,5,6), 
                       control = permControl(nperm=999)) 
summary(indvalrest)


###################################################
### code chunk number 19: indicspeciesTutorial.Rnw:158-159
###################################################
indvalrest$sign


###################################################
### code chunk number 20: indicspeciesTutorial.Rnw:167-169
###################################################
prefstat = strassoc(wetland, cluster=groups, func="A.g")
round(head(prefstat),3)


###################################################
### code chunk number 21: indicspeciesTutorial.Rnw:172-175
###################################################
prefstat = strassoc(wetland, cluster=groups, func="A.g", nboot = 199)
round(head(prefstat$lowerCI),3)
round(head(prefstat$upperCI),3)


###################################################
### code chunk number 22: indicspeciesTutorial.Rnw:182-185
###################################################
prefsign = signassoc(wetland, cluster=groups,  alternative = "two.sided", 
                     control = permControl(nperm=199)) 
head(prefsign)


###################################################
### code chunk number 23: indicspeciesTutorial.Rnw:193-194
###################################################
coverage(wetland, indvalori)


###################################################
### code chunk number 24: indicspeciesTutorial.Rnw:199-200
###################################################
coverage(wetland, indvalori, At = 0.8)


###################################################
### code chunk number 25: indicspeciesTutorial.Rnw:208-214
###################################################
plotcoverage(wetland, indvalori, group="1", lty=1)
plotcoverage(wetland, indvalori, group="2", lty=2, col="blue", add=TRUE)
plotcoverage(wetland, indvalori, group="3", lty=3, col="red", add=TRUE)
legend(x = 0.01, y=20, 
       legend=c("group 1","group 2", "group 3"),
       lty=c(1,2,3), col=c("black","blue","red"), bty="n")


###################################################
### code chunk number 26: indicspeciesTutorial.Rnw:226-228
###################################################
wetcomb = combinespecies(wetland, max.order = 2)$XC
dim(wetcomb)


###################################################
### code chunk number 27: indicspeciesTutorial.Rnw:231-234
###################################################
indvalspcomb = multipatt(wetcomb, groups, duleg = TRUE, 
                       control = permControl(nperm=999))
summary(indvalspcomb, indvalcomp = TRUE)


###################################################
### code chunk number 28: indicspeciesTutorial.Rnw:240-243
###################################################
B=strassoc(wetland, cluster=groups ,func="B") 
sel=which(B[,2]>0.2) 
sel


###################################################
### code chunk number 29: indicspeciesTutorial.Rnw:246-248
###################################################
sc= indicators(X=wetland[,sel], cluster=groups, group=2, verbose=TRUE, 
               At=0.5, Bt=0.2)


###################################################
### code chunk number 30: indicspeciesTutorial.Rnw:251-252
###################################################
print(sc, sqrtIVt = 0.6)


###################################################
### code chunk number 31: indicspeciesTutorial.Rnw:260-261
###################################################
coverage(sc)


###################################################
### code chunk number 32: indicspeciesTutorial.Rnw:264-265
###################################################
coverage(sc, At=0.8)


###################################################
### code chunk number 33: indicspeciesTutorial.Rnw:271-275
###################################################
plotcoverage(sc)
plotcoverage(sc, max.order=1, add=TRUE, lty=2, col="red")
legend(x=0.1, y=20, legend=c("Species combinations","Species singletons"), 
       lty=c(1,2), col=c("black","red"), bty="n")


###################################################
### code chunk number 34: indicspeciesTutorial.Rnw:282-284
###################################################
sc2=pruneindicators(sc, At=0.8, Bt=0.2, verbose=TRUE)
print(sc2)


